# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.0.2] 2023-08-04

Keeping this short, since no one is using this yet.

## Added
- Added an example for basic usage of the library

## Changed
- Reworked the `Chat` class to be more simple and easy to use.
- Updated tests to reflect the changes

## Fixed
- Fixed bugs in pyproject.toml and __init__.py

## [0.0.1] 2023-07-31
Initial Release

